summarylogtreecommitdiffstats
path: root/updates.sh
diff options
context:
space:
mode:
Diffstat (limited to 'updates.sh')
-rwxr-xr-xupdates.sh8
1 files changed, 7 insertions, 1 deletions
diff --git a/updates.sh b/updates.sh
index dee4439ea77e..71e40acba1e2 100755
--- a/updates.sh
+++ b/updates.sh
@@ -6,11 +6,17 @@ _version=$(git ls-remote --tags --refs --sort="version:refname" https://github.c
_version=${_version##*/}
_version=${_version%%-*}
_version=${_version//v/}
#Uncomment to use release candidates during pre-release testing
#_vrc=$(git ls-remote --tags --refs --sort="version:refname" https://github.com/skycoin/skywire.git | tail -n1 | grep -- -rc)
#if [[ $_vrc != "" ]]; then
# _vrc="-${_vrc##*-}"
#fi
+#get release candidate version from source repo
+_vrc=$(git ls-remote --tags --refs --sort="version:refname" https://github.com/skycoin/skywire.git | tail -n1 | grep -- -pr)
+if [[ $_vrc != "" ]]; then
+ _vrc="-${_vrc##*-}"
+fi
echo ${_version}
echo ${_vrc}
echo "updating checksums and version for PKGBUILD"
@@ -6,11 +6,17 @@ _version=$(git ls-remote --tags --refs --sort="version:refname" https://github.c
_version=${_version%%-*}
_version=${_version//v/}
-#Uncomment to use release candidates during pre-release testing
+#Uncomment to use release candidates or pre-releases for testing
+#get release candidate version from source repo
#_vrc=$(git ls-remote --tags --refs --sort="version:refname" https://github.com/skycoin/skywire.git | tail -n1 | grep -- -rc)
#if [[ $_vrc != "" ]]; then